@@ -3,7 +3,7 @@ use warnings;
 
 package HTTP::Async;
 
-our $VERSION = '0.16';
+our $VERSION = '0.18';
 
 use Carp;
 use Data::Dumper;
@@ -88,6 +88,8 @@ However in some circumstances you might wish to change these.
     poll_interval: 0.05 (seconds)
        proxy_host: ''
        proxy_port: ''
+       local_addr: ''
+       local_port: ''
        
 =head1 METHODS
 
@@ -136,7 +138,7 @@ sub _init {
 
 sub _next_id { return ++$_[0]->{current_id} }
 
-=head2 slots, timeout, max_request_time, poll_interval, max_redirects, proxy_host and proxy_port
+=head2 slots, timeout, max_request_time, poll_interval, max_redirects, proxy_host, proxy_port, local_addr, local_port
 
     $old_value = $async->slots;
     $new_value = $async->slots( $new_value );
@@ -150,7 +152,7 @@ Slots is the maximum number of parallel requests to make.
 
 my %GET_SET_KEYS = map { $_ => 1 } qw( slots poll_interval
   timeout max_request_time max_redirects
-  proxy_host proxy_port );
+  proxy_host proxy_port local_addr local_port);
 
 sub _add_get_set_key {
     my $class = shift;
@@ -243,7 +245,7 @@ sub add_with_opts {
     $async->poke;
 
 At fairly frequent intervals some housekeeping needs to performed - such as
-reading recieved data and starting new requests. Calling C<poke> lets the
+reading received data and starting new requests. Calling C<poke> lets the
 object do this and then return quickly. Usually you will not need to use this
 as most other methods do it for you.
 
@@ -639,6 +641,8 @@ sub _send_request {
     $args{Host}     = $uri->host;
     $args{PeerAddr} = $self->_get_opt( 'proxy_host', $id );
     $args{PeerPort} = $self->_get_opt( 'proxy_port', $id );
+    $args{LocalAddr} = $self->_get_opt('local_addr', $id );
+    $args{LocalPort} = $self->_get_opt('local_port', $id );
 
     my $request_is_to_proxy =
       ( $args{PeerAddr} || $args{PeerPort} )    # if either are set...
@@ -793,6 +797,10 @@ tests run ok in parallel.
 Josef Toman for fixing two bugs, one related to header handling and another
 related to producing an absolute URL correctly.
 
+Github user 'c00ler-' for adding LocalAddr and LocalPort support.
+
+rt.cpan.org user 'Florian (fschlich)' for typo in documentation.
+
 =head1 BUGS AND REPO
 
 Please submit all bugs, patches etc on github
